<?php
// vim: foldmethod=marker
/**
 *	Ethna_Filter.php
 *
 *	@author		Masaki Fujimoto <fujimoto@php.net>
 *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
 *	@package	Ethna
 *	@version	$Id: Ethna_Filter.php,v 1.3 2005/01/06 17:44:23 fujimoto Exp $
 */

// {{{ Ethna_Filter
/**
 *	ե졼Υե륿쥯饹
 *
 *	MojaviοǤʤäѤˡ¹˳ƼԤȤ
 *	ޤ
 *
 *	@author		Masaki Fujimoto <fujimoto@php.net>
 *	@access		public
 *	@package	Ethna
 */
class Ethna_Filter
{
	/**#@+
	 *	@access	private
	 */

	/**	@var	object	Ethna_Controller	controller֥ */
	var	$controller;

	/**	@var	object	Ethna_Controller	controller֥($controllerξά) */
	var	$ctl;

	/**	@var	object	Ethna_Config		ꥪ֥ */
	var	$config;

	/**	@var	object	Ethna_Logger		֥ */
	var $logger;

	/**#@-*/


	/**
	 *	Ethna_FilterΥ󥹥ȥ饯
	 *
	 *	@access	public
	 *	@param	object	Ethna_Controller	&$controller	ȥ饪֥
	 */
	function Ethna_Filter(&$controller)
	{
		// ֥Ȥ
		$this->controller =& $controller;
		$this->ctl =& $this->controller;

		$this->config =& $controller->getConfig();
		$this->logger =& $this->controller->getLogger();
	}

	/**
	 *	¹ե륿
	 *
	 *	@access	public
	 */
	function preFilter()
	{
	}

	/**
	 *	¹ե륿
	 *
	 *	@access	public
	 *	@param	string	$action_name	¹Ԥ륢̾
	 *	@return	string	null:ｪλ (string):¹Ԥ륢̾ѹ
	 */
	function preActionFilter($action_name)
	{
		return null;
	}

	/**
	 *	¹Ըե륿
	 *
	 *	@access	public
	 *	@param	string	$action_name	¹Ԥ줿̾
	 *	@param	string	$forward_name	¹Ԥ줿󤫤
	 */
	function postActionFilter($action_name, $forward_name)
	{
		return null;
	}

	/**
	 *	¹Ըե륿
	 *
	 *	@access	public
	 */
	function postFilter()
	{
	}
}
// }}}
?>
